#
# spec file for package golang-github-prometheus-promu
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel}
%global debug_package %{nil}
# Fix ERROR: No build ID note found in
%undefine _missing_build_ids_terminate_build
%endif

%define shortname promu

Name:           golang-github-prometheus-promu
Version:        0.17.0
Release:        4.2
Summary:        Prometheus Utility Tool
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/prometheus/promu
Source:         %{shortname}-%{version}.tar.gz
Source1:        vendor.tar.gz
# PATCH-FIX-OPENSUSE Do not pass -static to external linker by default
Patch2:         extldflags-no-static.patch
ExcludeArch:    s390
%if 0%{?rhel}
BuildRequires:  golang >= 1.21
%else
BuildRequires:  golang(API) >= 1.21
%endif

%description
The Prometheus Utility Tool is used by the Prometheus project to build other components.

%prep
%autosetup -a1 -p1 -n %{shortname}-%{version}

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build

%check
# execute the binary as a basic check
./%{shortname} --help
%if 0%{?rhel}
rm -f %{buildroot}/usr/lib/debug%{_bindir}/%{shortname}*.debug
rm -rf %{buildroot}/usr/lib/debug/.build-id/*
rm -rf %{buildroot}%{_usrsrc}/debug/%{name}-%{version}-*
%endif

%install
install -D -m 0755 %{shortname} "%{buildroot}/%{_bindir}/%{shortname}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{shortname}

%changelog
* Thu Feb  6 2025 Witek Bedyk <witold.bedyk@suse.com>
- Remove more debug files for Red Hat Enterprise Linux
* Mon Dec  9 2024 Witek Bedyk <witold.bedyk@suse.com>
- Do not auto-generate changelog entries
- Require Go >= 1.21 for building Red Hat Enterprise Linux packages
* Wed Dec  4 2024 Witek Bedyk <witold.bedyk@suse.com>
- Fix build error on Red Hat Enterprise Linux
* Sat Apr 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.17.0:
  * [FEATURE] Add codesign utility function #284
* Sat Apr 20 2024 opensuse_buildservice@ojkastl.de
- drop patch
  0001-do_not_discover_user_host_for_reproducible_builds.patch that
  was merged upstream
  (https://github.com/prometheus/promu/pull/267)
- BuildRequire go1.21 as upstream does
- Update to version 0.16.0:
  * [FEATURE] Do not discover user/host for reproducible builds
    [#267]
  * [BUGFIX] Fix example/prometheus build error #274
* Sat Feb 10 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * _service change disabled to manual per osc deprecation warning:
    WARNING: Command 'disabledrun/dr' is obsolete, please convert
    your _service to use 'manual' and then 'manualrun/mr' instead.
  * Define shortname corresponding to binary name when different
    from package name. Use shortname where applicable to normalize
    common lines across Go app packages, similar to name macro.
  * Drop BuildRequires: golang-packaging. The original macros for
    file movements into GOPATH are obsolete with Go modules. Macro
    go_nostrip is no longer needed with current binutils and Go.
  * Drop export CGO_ENABLED="0". Use the default unless there is a
    defined requirement or benefit.
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Remove ldflags -X entries for upstream import path and version.
    This information is embedded in binaries with go1.18+ and
    available via go version -m or runtime/debug.ReadBuildInfo().
  * Remove ldflags -s (Omit symbol table and debug info) and -w
    (Omit DWARF symbol table). This information is used to produce
    separate debuginfo packages and binaries are stripped for
    reduced size by GNU strip during RPM build.
  * Drop go build -o arg, default binary name is pkg of main()
  * Add basic %%check to execute binary --help
* Thu Dec 14 2023 Andreas Schwab <schwab@suse.de>
- extldflags-no-static.patch: Don't pass -extldflags -static by default
* Tue Aug  8 2023 Witek Bedyk <witold.bedyk@suse.com>
- Always set user and host build metadata to constant string to
  achieve reproducible builds (compare reproducible-builds.org)
- Add 0001-do_not_discover_user_host_for_reproducible_builds.patch
- Require Go >= 1.19 for building
- Require Go >= 1.18 for building Red Hat packages
* Tue Jul  4 2023 kastl@b1-systems.de
- Update to version 0.15.0:
  * Release v0.15.0
  * Bump golang.org/x/oauth2 from 0.8.0 to 0.9.0
  * Update common Prometheus files
  * Bump go.uber.org/atomic from 1.10.0 to 1.11.0
  * Update build
  * Add linux/riscv64 to default platforms
  * Bump github.com/prometheus/common from 0.39.0 to 0.42.0
  * Bump golang.org/x/oauth2 from 0.5.0 to 0.6.0
  * Bump github.com/prometheus/common from 0.37.0 to 0.39.0
  * Bump golang.org/x/oauth2 from 0.2.0 to 0.5.0
  * Bump golang.org/x/net from 0.2.0 to 0.7.0
  * Use unmarshalstrict
* Wed Mar 22 2023 Johannes Kastl <kastl@b1-systems.de>
- rework spec file to use obscpio
  - run tar and recompresss services at buildtime
* Tue Jan 10 2023 kastl@b1-systems.de
- Update to version 0.14.0:
  * Add the ability to override tags per GOOS
  * Remove ioutil
  * Update common Prometheus files (#232) (#224)
  * Validate environment variable value
  * Set build date from SOURCE_DATE_EPOCH
- drop patch 0001-Set-build-date-from-SOURCE_DATE_EPOCH.patch that is
  included upstream now
* Mon Oct 31 2022 Witek Bedyk <witold.bedyk@suse.com>
- Do not include source code
- Update to Go 1.18
* Tue Sep 27 2022 Dirk Müller <dmueller@suse.com>
- switch to go1.17 as upstream does (see https://github.com/prometheus/promu/blob/v0.13.0/.promu.yml)
- remove go_nostrip as it isn't necessary with 1.17 anymore
* Tue May 10 2022 Jordi Massaguer <jmassaguerpla@suse.com>
- Exclude s390 architecture.
* Tue Apr 26 2022 Witek Bedyk <witold.bedyk@suse.com>
- Set build date from last changelog modification (boo#1047218)
- Add 0001-Set-build-date-from-SOURCE_DATE_EPOCH.patch
* Fri Apr  1 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Adapted for Enterprise Linux build.
* Thu Mar  3 2022 ecsos@opensuse.org
- Update to version 0.13.0:
  * Release 0.13.0 (jsc#SLE-24138, jsc#SLE-24139)
  * Add deprecation note to pkg directory
  * Add windows/arm64
  * Update common Prometheus files
  * Fix typo
  * Release 0.12.0
  * Simplify CGO crossbuilds
  * Update common Prometheus files
  * Release 0.11.1
  * Fix build with "linux" platform
* Mon Mar  8 2021 Witek Bedyk <witold.bedyk@suse.com>
- Build requires Go 1.15
* Fri Feb  7 2020 Witek Bedyk <witold.bedyk@suse.com>
- Update to 0.5.0
  + Features:
  * Add support for aix/ppc64. #151
  * Fallback to git describe output if no VERSION. #130
  * Make extldflags extensible by configuration. #125
  + Enhancements:
  * cmd/release: add --timeout option. #142
  * cmd/release: create release in GitHub if none exists. #148
  * Avoid bind-mounting to allow building with a remote docker engine #95
  + Bug Fixes:
  * cmd/tarball: restore --prefix flag. #133
  * cmd/release: don't leak credentials in case of error. #136
- Use obs-service-go_modules
* Fri Feb  8 2019 Jan Fajerski <jan.fajerski@suse.com>
- Update to 0.2.0
  + Features:
  * Adding changes to support s390x
  * Add option to disable static linking
  * Add support for 32bit MIPS.
  * Added check_licenses Command to Promu
  + Enhancements:
  * Allow to customize nested options via env variables
  * Bump Go version to 1.11
  * Add warning if promu info is unable to determine repo info
  + Bug Fixes:
  * Fix build on SmartOS by not setting gcc's -static flag
  * Fix git repository url parsing
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 0.1.0
* Wed Mar 29 2017 moio@suse.com
- Initial version
